# 2021-09-07 - Investment Pool

Deployment of the `InvestmentPoolFactory`, for an initial iteration of Investment Pools. These Pools grant a large amount of power to their owner: they should only be used with care.

## Useful Files

- [`InvestmentPool` ABI](./abi/InvestmentPool.json)
